/**
 *
 * @defgroup nrf_vt_backend_config VT Backend Configuration
 * @{
 * @ingroup nrf_vt_backend
 */

/**@brief The SAADC channel number to use. Default: 0 */
#define NRF_VT_BACKEND_SAADC_CHANNEL

/**@brief The size (in samples) of each RX buffer. Default: 1024
 * The total buffer space used will be equal to
 * `NRF_VT_BACKEND_RX_BUFFER_SIZE` * (2 + `NRF_VT_BACKEND_COPY_BUFFER_COUNT`) * sizeof(int16_t) Bytes
 * 
 */
#define NRF_VT_BACKEND_RX_BUFFER_SIZE

/**@brief  The amount of reserve buffers to use for processing. Default: 2, Min: 1
 * Increasing the amount of extra buffers may lead to less overrun errors due to buffer exhaustion,
 * as it increases the minimum time interval during which processing must finish.
 *
 */
#define NRF_VT_BACKEND_COPY_BUFFER_COUNT  

/**@brief The PWM module to use for transmission. Default: 0
 */
#define NRF_VT_BACKEND_PWM_MODULE

/**@brief The base clock rate used for the PWM. Default: NRF_PWM_CLK_8MHz  
 * May be set to any of the `nrf_pwm_clk_t`.
 * The COUNTERTOP value used for the PWM is set to `base clock rate / bitrate`.
 * You may need to change this value if using very high or very low bitrates.
 */
#define NRF_VT_BACKEND_PWM_BASE_CLOCK  

/**@brief The size (in PWM values) of the TX buffer. Default: 4096
 * Increasing the TX buffer size will make it possible to send more data at once.
 * The total buffer space used will be equal to
 * `NRF_VT_BACKEND_TX_BUFFER_SIZE` * sizeof(uint16_t) Bytes
 */
#define NRF_VT_BACKEND_TX_BUFFER_SIZE 

/**@brief The amount of frame casts available. Default: 2
 */
#define NRF_VT_BACKEND_FRAME_CAST_COUNT  


/**@brief The value of the start bit(s). Possible values: 0 / 1
 */
#define NRF_VT_START_BIT_VALUE 

/**@brief The amount of start bits. Possible values: 1-8 (inclusive)
 */
#define NRF_VT_START_BITS

/**@brief The value of the stop bit(s). Possible values: 0 / 1
 */
#define NRF_VT_STOP_BIT_VALUE  

/**@brief The amount of stop bits. Possible values: 1-8 (inclusive)
 */
#define NRF_VT_STOP_BITS  

/**@brief Delay in bit times between each sent frame. Possible values: 1-8 (inclusive)
 */
#define NRF_VT_END_DELAY

/**@brief Idle line value. Possible values: 0 / 1
 */
#define NRF_VT_DEFAULT_LINE_VALUE  

/**@brief Constant indicating whether the payload should be sent lsbit-first or msbit-first. Possible values: true / false
 */
#define NRF_VT_LSBIT_FIRST  

/** @} */
