import sys
import os.path
import os

import tkinter as tk
from tkinter import filedialog

from kb import KBHit

TEMPLATE_PLACEHOLDER = "REPLACE_ME_NOW=0"
SDK_ROOT_STR = "SDK_ROOT={}"
SDK_LIB_DST = "components/libraries/nrf_vt"
LIB_DST = "nrf_vt"

KEYCODE_CTRL_C = 3
KEYCODE_CTRL_D = 4
KEYCODE_ESC = 27

SYMLINK_SUCCESS = 0
SYMLINK_EXISTS = 1
SYMLINK_PERMISSION = 2
SYMLINK_NOTIMPL = 3

def is_exit_key(key):
	return ord(key) in [KEYCODE_CTRL_C, KEYCODE_CTRL_D, KEYCODE_ESC]

def input_selection(prompt, options=None):
	selected = None
	kb = KBHit()
	while selected is None:
		print(prompt)
		if options is not None:
			for i, option in enumerate(options):
				print("\t{}) {}".format(i + 1, option))
			c = kb.getch()
			if is_exit_key(c):
				break
			try:
				c = int(c) - 1
				if 0 <= c < len(options):
					selected = int(c)
					break
			except ValueError:
				pass
		else:
			kb.getch()
			break
				
	kb.set_normal_term()
	return selected
	
	
def input_wait_for_key(prompt):
	kb = KBHit()
	print(prompt)
	c = kb.getch()
	kb.set_normal_term()
	return c
	

def generate_project_files(template_paths, project_rel_path, sdk_path):
	project_paths = []
	sdk_root_string = SDK_ROOT_STR.format(sdk_path)
	for template_path in template_paths:
		template_split = os.path.split(template_path)
		project_path = os.path.abspath(os.path.join(template_split[0], project_rel_path, os.path.splitext(template_split[1])[0] + ".emProject"))
		project_paths.append(project_path)
		with open(template_path, "r") as tf:
			template_content = tf.read()
			project_content = template_content.replace(TEMPLATE_PLACEHOLDER, sdk_root_string, 1)
		with open(project_path, "w") as pf:
			pf.write(project_content)
	return project_paths
	

def sdk_path_valid(sdk_path):
	# Basic dumb validation
	return os.path.exists(os.path.join(sdk_path, os.path.split(SDK_LIB_DST)[0]))
	

def generate_sdk_symlink(sdk_path):
	symlink_path = os.path.join(sdk_path, SDK_LIB_DST)
	target_path = os.path.abspath(LIB_DST)
	if os.path.exists(symlink_path):
		return SYMLINK_EXISTS
	try:
		os.symlink(target_path, symlink_path, target_is_directory=True)
		return SYMLINK_SUCCESS
	except OSError:
		return SYMLINK_PERMISSION
	except NotImplementedError:
		return SYMLINK_NOTIMPL

def exit_program(code):
	print("Exiting...")
	sys.exit(code)	
	
TEMPLATE_PATHS = {
	"SDK 15.0.0": ["ble_app_uart_sdk_15.0.0/pca10040/s132/ses/template/ble_app_uart_vt_pca10040_s132.template",
				   "ble_app_uart_sdk_15.0.0/pca10056/s140/ses/template/ble_app_uart_vt_pca10056_s140.template"],
	"SDK 15.2.0": ["ble_app_uart_sdk_15.2.0/pca10040/s132/ses/template/ble_app_uart_vt_pca10040_s132.template",
				   "ble_app_uart_sdk_15.2.0/pca10056/s140/ses/template/ble_app_uart_vt_pca10056_s140.template"]
}

SDK_OPTIONS = ["SDK 15.0.0", "SDK 15.2.0"]

sdk_version = input_selection("\nSelect your SDK version by pressing [{}-{}] or press ESC to exit".format(1, len(SDK_OPTIONS)), SDK_OPTIONS)

if sdk_version is None:
	exit_program(1)

sdk_version_string = SDK_OPTIONS[sdk_version]	
print("\nSelected", sdk_version_string)

root = tk.Tk()
root.withdraw()

while True:
	key = input_wait_for_key("\nLocate the root directory of {}.\nPress any key to open the file browser...".format(sdk_version_string))	
	if is_exit_key(key):
		exit_program(1)
	sdk_path = filedialog.askdirectory(initialdir="$USERPROFILE$")
	if sdk_path == "":
		print("Canceled. Exiting...")
		sys.exit(1)
	elif not sdk_path_valid(sdk_path):
		print("Invalid SDK path selected")
	else:
		break

project_paths = generate_project_files(TEMPLATE_PATHS[sdk_version_string], "../", sdk_path)
print("\nGenerated project files at:")
for p in project_paths:
	print(p)

symlink_path = symlink_path = os.path.join(sdk_path, SDK_LIB_DST)
symlink_success = generate_sdk_symlink(sdk_path)
if symlink_success == SYMLINK_SUCCESS:
	print("\nSymlinked library path at", symlink_path)
elif symlink_success == SYMLINK_EXISTS:
	print("\nUnable to create symlink at {}. The file already exists.".format(symlink_path))
elif symlink_success == SYMLINK_PERMISSION:
	print("\nUnable to create symlink at {}. You do not have permission to create symlinks.".format(symlink_path))
elif symlink_success == SYMLINK_NOTIMPL:
	print("\nUnable to create symlink at {}. Symlinks are not supported on this version of Windows.".format(symlink_path))

input_wait_for_key("Press any key to open the pca10040 project folder...")
for p in project_paths:
	if "pca10040" in p.lower():
		os.startfile(os.path.normpath(os.path.split(p)[0]))
	
exit_program(0)


